pub enum BitcoinRpcError {
Request {
method: String,
source: Error,
},
ReadBody {
method: String,
source: Error,
},
Decode {
method: String,
body: String,
source: Error,
},
DecodeResult {
method: String,
source: Error,
},
HttpStatus {
method: String,
status: u16,
},
Rpc {
method: String,
code: i64,
message: String,
},
}Expand description
Error returned by the Bitcoin Core JSON-RPC client.
Variants
Request
The HTTP request failed before a response was received.
ReadBody
The response body could not be read.
Decode
The response body was not a valid Bitcoin Core JSON-RPC response.
Fields
DecodeResult
The JSON-RPC result field could not be decoded into the requested type.
HttpStatus
Bitcoin Core returned a non-success HTTP status.
Rpc
Bitcoin Core returned a JSON-RPC error object.