ConfigError

Enum ConfigError 

pub enum ConfigError {
Show 13 variants EmptyAlias, InvalidAlias(String), DuplicateAlias(String), EmptyNodes, EmptyImage { field: &'static str, }, ImageContainsWhitespace { field: &'static str, image: String, }, ImageMissingTagOrDigest { field: &'static str, image: String, }, InvalidNodesPerBitcoind, InvalidStartupRetryAttempts, InvalidStartupRetryInterval, InvalidClusterSubnet(String), InvalidEnvUsize { var: String, value: String, }, InvalidEnvBool { var: String, value: String, },
}
Configuration validation error.

Variants



EmptyAlias

A node alias was empty.



InvalidAlias(String)

A node alias contained unsupported characters.



DuplicateAlias(String)

The same node alias was configured more than once.



EmptyNodes

The config contained no LND nodes.



EmptyImage

A Docker image field was empty.

Fields

field: &'static str

Config field name.



ImageContainsWhitespace

A Docker image field contained whitespace.

Fields

field: &'static str

Config field name.

image: String

Invalid Docker image reference.



ImageMissingTagOrDigest

A Docker image did not include a tag or digest.

Fields

field: &'static str

Config field name.

image: String

Invalid Docker image reference.



InvalidNodesPerBitcoind

nodes_per_bitcoind was zero.



InvalidStartupRetryAttempts

Retry attempts were zero.



InvalidStartupRetryInterval

Retry interval was zero.



InvalidClusterSubnet(String)

A configured Docker network subnet was not valid IPv4 CIDR notation.



InvalidEnvUsize

An integer environment override could not be parsed.

Fields

var: String

Environment variable name.

value: String

Invalid environment variable value.



InvalidEnvBool

A boolean environment override could not be parsed.

Fields

var: String

Environment variable name.

value: String

Invalid environment variable value.