pub enum SpawnError {
Show 16 variants
Config(ConfigError),
Docker(Box<DockerError>),
BitcoinCore {
group_index: usize,
source: Box<BitcoinCoreError>,
},
BitcoinPeer {
from_group: usize,
to_group: usize,
source: Box<BitcoinRpcError>,
},
BitcoinRpc {
group_index: usize,
source: Box<BitcoinRpcError>,
},
BitcoinSyncTimeout {
attempts: usize,
last_tips: Vec<String>,
},
MissingBitcoindIp {
group_index: usize,
},
UnknownNode {
alias: String,
},
UnknownBitcoindGroup {
group_index: usize,
},
InvalidFundingAmount {
amount_btc: f64,
},
MissingLndIp {
alias: String,
},
Lnd {
alias: String,
source: Box<LndError>,
},
ConnectNodes(LndConnectError),
InvalidClusterNetworkSubnet {
subnet: String,
message: String,
},
StaticIpUnavailable {
subnet: String,
offset: u32,
largest_usable_offset: u32,
},
StartupCleanup {
cluster_id: String,
startup_error: String,
source: Box<DockerError>,
},
}Expand description
Error returned by cluster lifecycle and orchestration operations.
Variants
Config(ConfigError)
Invalid cluster configuration.
Docker(Box<DockerError>)
Docker operation failed.
BitcoinCore
Failed to spawn a Bitcoin Core chain group.
Fields
source: Box<BitcoinCoreError>Underlying Bitcoin Core error.
BitcoinPeer
Failed to connect two Bitcoin Core chain groups.
Fields
source: Box<BitcoinRpcError>Underlying Bitcoin RPC error.
BitcoinRpc
Bitcoin Core RPC failed for a chain group.
Fields
source: Box<BitcoinRpcError>Underlying Bitcoin RPC error.
BitcoinSyncTimeout
Bitcoin Core chain groups did not converge on a common tip.
Fields
MissingBitcoindIp
A Bitcoin Core container had no Docker bridge IP.
UnknownNode
A requested LND node alias does not exist.
UnknownBitcoindGroup
A requested Bitcoin Core chain group does not exist.
InvalidFundingAmount
A funding amount was not positive and finite.
MissingLndIp
An LND container had no Docker bridge IP.
Lnd
LND operation failed.
ConnectNodes(LndConnectError)
Connecting to all LND nodes failed.
InvalidClusterNetworkSubnet
The managed Docker network did not report a usable IPv4 subnet.
The managed Docker network subnet was too small for this cluster.
StartupCleanup
Startup failed and the attempted cleanup also failed.