pub struct BitcoinCore {
pub container: SpawnedContainer,
pub auth: BitcoinRpcAuth,
pub rpc: BitcoinRpcClient,
pub wallet_rpc: BitcoinRpcClient,
pub rpc_socket: String,
pub p2p_socket: String,
}Expand description
A running Bitcoin Core container and its RPC handles.
Fields
container: SpawnedContainerDocker container metadata.
auth: BitcoinRpcAuthRPC authentication generated for the node.
rpc: BitcoinRpcClientRPC client for node-level methods.
wallet_rpc: BitcoinRpcClientRPC client scoped to the default wallet.
rpc_socket: StringHost RPC socket, usually 127.0.0.1:<port>.
p2p_socket: StringHost P2P socket, usually 127.0.0.1:<port>.
Implementations
Sourceimpl BitcoinCore
impl BitcoinCore
Sourcepub async fn spawn(
docker: &DockerClient,
config: BitcoinCoreConfig,
) -> Result<Self, BitcoinCoreError>
pub async fn spawn( docker: &DockerClient, config: BitcoinCoreConfig, ) -> Result<Self, BitcoinCoreError>
Spawn a Bitcoin Core container and wait until RPC is ready.
Sourcepub async fn wait_ready(&self) -> Result<BlockchainInfo, BitcoinCoreError>
pub async fn wait_ready(&self) -> Result<BlockchainInfo, BitcoinCoreError>
Wait for getblockchaininfo to succeed using the default retry policy.
Sourcepub async fn prepare_mining_wallet(
&self,
) -> Result<Vec<String>, BitcoinCoreError>
pub async fn prepare_mining_wallet( &self, ) -> Result<Vec<String>, BitcoinCoreError>
Create/load the default wallet and mine enough blocks to mature coinbase funds.