pub struct SpawnLndBuilder { /* private fields */ }Expand description
Builder for SpawnLndConfig.
Implementations
Sourceimpl SpawnLndBuilder
impl SpawnLndBuilder
Sourcepub fn node_config(self, node: NodeConfig) -> Self
pub fn node_config(self, node: NodeConfig) -> Self
Add one fully configured LND node.
Sourcepub fn bitcoind_image(self, image: impl Into<String>) -> Self
pub fn bitcoind_image(self, image: impl Into<String>) -> Self
Override the Bitcoin Core Docker image.
Sourcepub fn nodes_per_bitcoind(self, count: usize) -> Self
pub fn nodes_per_bitcoind(self, count: usize) -> Self
Set how many LND nodes share each Bitcoin Core container.
Sourcepub fn keep_containers(self, keep: bool) -> Self
pub fn keep_containers(self, keep: bool) -> Self
Preserve containers instead of removing them during shutdown or rollback.
Sourcepub fn startup_retry_policy(self, policy: RetryPolicy) -> Self
pub fn startup_retry_policy(self, policy: RetryPolicy) -> Self
Set the startup retry policy.
Sourcepub fn startup_retry(self, attempts: usize, interval_ms: usize) -> Self
pub fn startup_retry(self, attempts: usize, interval_ms: usize) -> Self
Set the startup retry policy from attempt and interval values.
Sourcepub fn cluster_subnet(self, subnet: impl Into<String>) -> Self
pub fn cluster_subnet(self, subnet: impl Into<String>) -> Self
Set the IPv4 subnet for the managed Docker bridge network.
Sourcepub fn build(self) -> Result<SpawnLndConfig, ConfigError>
pub fn build(self) -> Result<SpawnLndConfig, ConfigError>
Build and validate a SpawnLndConfig.
Sourcepub async fn spawn(self) -> Result<SpawnedCluster, SpawnError>
pub async fn spawn(self) -> Result<SpawnedCluster, SpawnError>
Build a config and spawn the cluster.