pub struct StartupRollback<'a> { /* private fields */ }Expand description
Tracks containers that should be removed if startup fails.
Implementations
Sourceimpl<'a> StartupRollback<'a>
impl<'a> StartupRollback<'a>
Sourcepub fn record(&mut self, container: &SpawnedContainer)
pub fn record(&mut self, container: &SpawnedContainer)
Record a container for later rollback.
Sourcepub fn record_id(&mut self, container_id: impl Into<String>)
pub fn record_id(&mut self, container_id: impl Into<String>)
Record a container id for later rollback.
Sourcepub fn container_ids(&self) -> &[String]
pub fn container_ids(&self) -> &[String]
Return currently tracked container ids.
Sourcepub fn disarm(self) -> Vec<String>
pub fn disarm(self) -> Vec<String>
Disarm the guard and return tracked ids without removing containers.
Sourcepub async fn rollback(self) -> Result<CleanupReport, DockerError>
pub async fn rollback(self) -> Result<CleanupReport, DockerError>
Remove all tracked containers and disarm the guard.